# Complain

**THIS PROJECT IS STILL IN A BETA PHASE.**

Official repository for the complain package.

This project uses [Scott Pakin's automatic complaint-letter generator](https://www.pakin.org/complaint?) and allows you to pull complaints through it.

## DISCLAIMER

**By installing and using this package you automatically agree to these terms.**

Scott Pakin's Automatic Complaint-Letter Generator is a program that automatically generates humorously bombastic complaint letters by randomly stitching together words and phrases into meaningless but negative-sounding grandiloquence. By clicking Agree below, you agree to the following terms:

1. You understand that any comments, views, or opinions you read on this site cannot be considered to be those of Scott Pakin.
2. You agree to hold Scott Pakin blameless for any liability related to any material appearing on this site.